//-----------------------------------------------------------------------------
//
//  Descriptors.h
//
//  Stylophone Studio 5
//  A USB MIDI controllable reproduction of the original 1968 Stylophone
//
//  Copyright (c) 2011 Simon Inns
//
//  Permission is hereby granted, free of charge, to any person obtaining a
//  copy of this software and associated documentation files (the "Software"),
//  to deal in the Software without restriction, including without limitation
//  the rights to use, copy, modify, merge, publish, distribute, sublicense,
//  and/or sell copies of the Software, and to permit persons to whom the
//  Software is furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//  DEALINGS IN THE SOFTWARE.
//
//  Web:    http://www.waitingforfriday.com
//  Email:  simon.inns@gmail.com
//
//-----------------------------------------------------------------------------

#ifndef _DESCRIPTORS_H_
#define _DESCRIPTORS_H_

// Includes:
#include "LUFA/Drivers/USB/USB.h"
#include <avr/pgmspace.h>

// Macros:
// Endpoint number of the MIDI streaming data IN endpoint, for device-to-host data transfers.
#define MIDI_STREAM_IN_EPNUM        1

// Endpoint number of the MIDI streaming data OUT endpoint, for host-to-device data transfers.
#define MIDI_STREAM_OUT_EPNUM       2

// Endpoint size in bytes of the Audio isochronous streaming data IN and OUT endpoints.
#define MIDI_STREAM_EPSIZE          64

// Type Defines:
// Type define for the device configuration descriptor structure. This must be defined in the
// application code, as the configuration descriptor contains several sub-descriptors which
// vary between devices, and which describe the device's usage to the host.

typedef struct
{
	USB_Descriptor_Configuration_Header_t     Config;

	// MIDI Audio Control Interface
	USB_Descriptor_Interface_t                Audio_ControlInterface;
	USB_Audio_Descriptor_Interface_AC_t       Audio_ControlInterface_SPC;

	// MIDI Audio Streaming Interface
	USB_Descriptor_Interface_t                Audio_StreamInterface;
	USB_MIDI_Descriptor_AudioInterface_AS_t   Audio_StreamInterface_SPC;
	USB_MIDI_Descriptor_InputJack_t           MIDI_In_Jack_Emb;
	USB_MIDI_Descriptor_InputJack_t           MIDI_In_Jack_Ext;
	USB_MIDI_Descriptor_OutputJack_t          MIDI_Out_Jack_Emb;
	USB_MIDI_Descriptor_OutputJack_t          MIDI_Out_Jack_Ext;
	USB_Audio_Descriptor_StreamEndpoint_Std_t MIDI_In_Jack_Endpoint;
	USB_MIDI_Descriptor_Jack_Endpoint_t       MIDI_In_Jack_Endpoint_SPC;
	USB_Audio_Descriptor_StreamEndpoint_Std_t MIDI_Out_Jack_Endpoint;
	USB_MIDI_Descriptor_Jack_Endpoint_t       MIDI_Out_Jack_Endpoint_SPC;
	} USB_Descriptor_Configuration_t;

// Function Prototypes
uint16_t CALLBACK_USB_GetDescriptor(
	const uint16_t wValue,
	const uint8_t wIndex,
	const void** const DescriptorAddress)
	ATTR_WARN_UNUSED_RESULT ATTR_NON_NULL_PTR_ARG(3);

#endif

