//-----------------------------------------------------------------------------
//
//  keyboard.h
//
//  Stylophone Studio 5
//  A USB MIDI controllable reproduction of the original 1968 Stylophone
//
//  Copyright (c) 2011 Simon Inns
//
//  Permission is hereby granted, free of charge, to any person obtaining a
//  copy of this software and associated documentation files (the "Software"),
//  to deal in the Software without restriction, including without limitation
//  the rights to use, copy, modify, merge, publish, distribute, sublicense,
//  and/or sell copies of the Software, and to permit persons to whom the
//  Software is furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//  DEALINGS IN THE SOFTWARE.
//
//  Web:    http://www.waitingforfriday.com
//  Email:  simon.inns@gmail.com
//
//-----------------------------------------------------------------------------

#ifndef KEYBOARD_H_
#define KEYBOARD_H_

// Keyboard debounce amount
#define KEYBOARD_DEBOUNCE_AMOUNT 10

#define KEY_READ		1
#define KEY_NOT_READ	0

// ADC Values with 5% tolerance resistors
#define ADC_POSL1	84
#define ADC_POSL2	158
#define ADC_POSL3	219
#define ADC_POSL4	272
#define ADC_POSL5	571
#define ADC_POSL6	700
#define ADC_POSL7	772
#define ADC_POSL8	819
#define ADC_POSL9	877
#define ADC_POSL10	909

#define ADC_POSH1	102
#define ADC_POSH2	186
#define ADC_POSH3	256
#define ADC_POSH4	313
#define ADC_POSH5	623
#define ADC_POSH6	743
#define ADC_POSH7	809
#define ADC_POSH8	850
#define ADC_POSH9	901
#define ADC_POSH10	928

// Function prototypes
void keyboardInitialise(void);
uint8_t keyboardPerformADC(void);
void keyboardPoll(void);
uint8_t keyboardGetKeyOffEvents(void);
uint8_t keyboardGetKeyOnEvents(void);

#endif /* KEYBOARD_H_ */