//-----------------------------------------------------------------------------
//
//  leds.c
//
//  Stylophone Studio 5
//  A USB MIDI controllable reproduction of the original 1968 Stylophone
//
//  Copyright (c) 2011 Simon Inns
//
//  Permission is hereby granted, free of charge, to any person obtaining a
//  copy of this software and associated documentation files (the "Software"),
//  to deal in the Software without restriction, including without limitation
//  the rights to use, copy, modify, merge, publish, distribute, sublicense,
//  and/or sell copies of the Software, and to permit persons to whom the
//  Software is furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//  DEALINGS IN THE SOFTWARE.
//
//  Web:    http://www.waitingforfriday.com
//  Email:  simon.inns@gmail.com
//
//-----------------------------------------------------------------------------

// Global includes
#include <avr/io.h>

// Local includes
#include "leds.h"

// Initialise the LEDs
void ledInitialise(void)
{
	// Set port directions
	DDRB |= (LED_BIGREEN | LED_BIRED | LED_VUSB | LED_MIDIIN | LED_MIDIOUT);
	
	// Set all pins to off
	PORTB &= ~(LED_BIGREEN | LED_BIRED | LED_VUSB | LED_MIDIIN | LED_MIDIOUT);
}

// Turn an LED on
void ledOn(uint8_t ledNumber)
{
	PORTB |= (ledNumber & (LED_BIGREEN | LED_BIRED | LED_VUSB | LED_MIDIIN | LED_MIDIOUT));
}

// Turn an LED off
void ledOff(uint8_t ledNumber)
{
	PORTB &= ~(ledNumber & (LED_BIGREEN | LED_BIRED | LED_VUSB | LED_MIDIIN | LED_MIDIOUT));
}