//-----------------------------------------------------------------------------
//
//  stylophone.h
//
//  Stylophone Studio 5
//  A USB MIDI controllable reproduction of the original 1968 Stylophone
//
//  Copyright (c) 2011 Simon Inns
//
//  Permission is hereby granted, free of charge, to any person obtaining a
//  copy of this software and associated documentation files (the "Software"),
//  to deal in the Software without restriction, including without limitation
//  the rights to use, copy, modify, merge, publish, distribute, sublicense,
//  and/or sell copies of the Software, and to permit persons to whom the
//  Software is furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//  DEALINGS IN THE SOFTWARE.
//
//  Web:    http://www.waitingforfriday.com
//  Email:  simon.inns@gmail.com
//
//-----------------------------------------------------------------------------

#ifndef STYLOPHONE_H_
#define STYLOPHONE_H_

// Definitions
#define TUNING_BASS		0
#define TUNING_STANDARD	1
#define TUNING_TREBLE	2

#define VIBRATO_OFF		0
#define VIBRATO_ON		1

// PORTC pins
#define STANDARD_GAIN		(1 << 6)

// PORTD pins
#define VIBRATO_PIN			(1 << 0)
#define STANDARD_PIN		(1 << 1)
#define BASS_PIN			(1 << 2)
#define TREBLE_PIN			(1 << 3)
#define TREBLE_ATK_PIN		(1 << 4)
#define STANDARD_ATK_PIN	(1 << 5)

#define FREQ_IN_PIN			(1 << 6)
#define FREQ_CONTROL_PIN	(1 << 7)

// DAC out on PC7
#define DAC_OUT_PIN			(1 << 7)

// Define the tuning error range
#define TUNING_ERROR_RANGE 200

// Function prototypes
void stylophoneInitialise(void);
void stylophoneTuning(uint8_t tuningMode);
uint8_t stylophoneTuningStatus(void);
void stylophoneVibrato(uint8_t vibratoSetting);
void stylophoneTune(void);
uint16_t getDacValueForNote(uint8_t note, uint8_t tuning);

// Internal functions exposed for testing
void setDac(uint16_t dacValue);
uint16_t calculateDacValueForFrequency(uint16_t frequency, uint8_t tuningMode);
uint16_t measureFrequency(void);
uint16_t measureDacValueForFrequency(uint16_t frequency, uint8_t tuningMode);

#endif /* STYLOPHONE_H_ */